@@ -259,7 +259,9 @@ class Settings:
                 loader_identifier="init_settings_module",
             )
         for key, value in kwargs.items():
-            self.set(key, value, loader_identifier="init_kwargs")
+            self.set(
+                key, value, loader_identifier="init_kwargs", validate=False
+            )
         # execute loaders only after setting defaults got from kwargs
         self._defaults = kwargs
 
@@ -476,23 +478,24 @@ class Settings:
             sysenv_fallback = self._store.get("SYSENV_FALLBACK_FOR_DYNACONF")
 
         nested_sep = self._store.get("NESTED_SEPARATOR_FOR_DYNACONF")
-        if nested_sep and nested_sep in key:
-            # turn FOO__bar__ZAZ in `FOO.bar.ZAZ`
-            key = key.replace(nested_sep, ".")
+        if isinstance(key, str):
+            if nested_sep and nested_sep in key:
+                # turn FOO__bar__ZAZ in `FOO.bar.ZAZ`
+                key = key.replace(nested_sep, ".")
 
-        if dotted_lookup is empty:
-            dotted_lookup = self._store.get("DOTTED_LOOKUP_FOR_DYNACONF")
+            if dotted_lookup is empty:
+                dotted_lookup = self._store.get("DOTTED_LOOKUP_FOR_DYNACONF")
 
-        if "." in key and dotted_lookup:
-            return self._dotted_get(
-                dotted_key=key,
-                default=default,
-                cast=cast,
-                fresh=fresh,
-                parent=parent,
-            )
+            if "." in key and dotted_lookup:
+                return self._dotted_get(
+                    dotted_key=key,
+                    default=default,
+                    cast=cast,
+                    fresh=fresh,
+                    parent=parent,
+                )
 
-        key = upperfy(key)
+            key = upperfy(key)
 
         # handles system environment fallback
         if default is None:
@@ -604,9 +607,8 @@ class Settings:
     loaded_namespaces = loaded_envs
 
     @property
-    def loaded_by_loaders(self):
+    def loaded_by_loaders(self):  # pragma: no cover
         """Gets the internal mapping of LOADER -> values"""
-        # return {k.loader:data for k, data in self._loaded_by_loaders}
         return self._loaded_by_loaders
 
     def from_env(self, env="", keep=False, **kwargs):
@@ -810,8 +812,8 @@ class Settings:
         """
         env = env or self.ENV_FOR_DYNACONF
 
-        if not isinstance(env, str) or "_" in env or " " in env:
-            raise ValueError("env should be a string without _ or spaces")
+        if not isinstance(env, str) or " " in env:
+            raise ValueError("env should be a string without spaces")
 
         env = env.upper()
 
@@ -913,7 +915,7 @@ class Settings:
     ):
         """Set a value storing references for the loader
 
-        :param key: The key to store
+        :param key: The key to store. Can be of any type.
         :param value: The raw value to parse and store
         :param loader_identifier: Optional loader name e.g: toml, yaml etc.
                                   Or isntance of SourceMetadata
@@ -938,20 +940,22 @@ class Settings:
         if dotted_lookup is empty:
             dotted_lookup = self.get("DOTTED_LOOKUP_FOR_DYNACONF")
         nested_sep = self.get("NESTED_SEPARATOR_FOR_DYNACONF")
-        if nested_sep and nested_sep in key:
-            key = key.replace(nested_sep, ".")  # FOO__bar -> FOO.bar
 
-        if "." in key and dotted_lookup is True:
-            return self._dotted_set(
-                key,
-                value,
-                loader_identifier=source_metadata,
-                tomlfy=tomlfy,
-                validate=validate,
-            )
+        if isinstance(key, str):
+            if nested_sep and nested_sep in key:
+                key = key.replace(nested_sep, ".")  # FOO__bar -> FOO.bar
+
+            if "." in key and dotted_lookup is True:
+                return self._dotted_set(
+                    key,
+                    value,
+                    loader_identifier=source_metadata,
+                    tomlfy=tomlfy,
+                    validate=validate,
+                )
+            key = upperfy(key.strip())
 
         parsed = parse_conf_data(value, tomlfy=tomlfy, box_settings=self)
-        key = upperfy(key.strip())
 
         # Fix for #869 - The call to getattr trigger early evaluation
         existing = (
@@ -983,7 +987,8 @@ class Settings:
             else:
                 parsed = parsed.unwrap()
 
-        if existing is not None and existing != parsed:
+        should_merge = existing is not None and existing != parsed
+        if should_merge:
             # `dynaconf_merge` used in file root `merge=True`
             if merge and merge is not empty:
                 source_metadata = source_metadata._replace(merged=True)
@@ -1001,7 +1006,12 @@ class Settings:
         # Set the parsed value
         self.store[key] = parsed
         self._deleted.discard(key)
-        super().__setattr__(key, parsed)
+
+        # check if str because we can't directly set/get non-str with obj. e.g.
+        #     setting.1
+        #     settings.(1,2)
+        if isinstance(key, str):
+            super().__setattr__(key, parsed)
 
         # Track history for inspect, store the raw_value
         if source_metadata in self._loaded_by_loaders:
